@@ -337,6 +337,15 @@ class Jira(AtlassianRestAPI):
     def issue(self, key, fields='*all'):
         return self.get('rest/api/2/issue/{0}?fields={1}'.format(key, fields))
 
+    def get_issue_changelog(self, issue_key):
+        """
+        Get issue related change log
+        :param issue_key:
+        :return:
+        """
+        url = 'rest/api/2/issue/{}?expand=changelog'.format(issue_key)
+        return (self.get(url) or {}).get('changelog')
+
     def issue_add_json_worklog(self, key, worklog):
         """
 
@@ -509,6 +518,24 @@ class Jira(AtlassianRestAPI):
             limit=limit)
         return self.get(url)
 
+    def get_assignable_users_for_issue(self, issue_key, username=None, start=0, limit=50):
+        """
+            Provide assignable users for issue
+            :param issue_key:
+            :param username: OPTIONAL: Can be used to chaeck if user can be assigned
+            :param start: OPTIONAL: The start point of the collection to return. Default: 0.
+            :param limit: OPTIONAL: The limit of the number of users to return, this may be restricted by
+                    fixed system limits. Default by built-in method: 50
+            :return:
+        """
+        url = 'rest/api/2/user/assignable/search?issueKey={issue_key}&startAt={start}&maxResults={limit}'.format(
+            issue_key=issue_key,
+            start=start,
+            limit=limit)
+        if username:
+            url += '&username={username}'.format(username=username)
+        return self.get(url)
+
     def get_groups(self, query=None, exclude=None, limit=20):
         """
         REST endpoint for searching groups in a group picker
@@ -641,6 +668,30 @@ class Jira(AtlassianRestAPI):
         url = 'rest/api/2/issue/{0}'.format(issue_key)
         return self.put(url, data={'fields': fields})
 
+    def issue_add_watcher(self, issue_key, user):
+        """
+        Start watching issue
+        :param issue_key:
+        :param user:
+        :return:
+        """
+        log.warning('Adding user {user} to "{issue_key}" watchers'.format(issue_key=issue_key, user=user))
+        data = {'': user}
+        return self.post('rest/api/2/issue/{issue_key}/watchers'.format(issue_key=issue_key), data=data)
+
+    def assign_issue(self, issue, assignee=None):
+        """Assign an issue to a user. None will set it to unassigned. -1 will set it to Automatic.
+        :param issue: the issue ID or key to assign
+        :type issue: int or str
+        :param assignee: the user to assign the issue to
+        :type assignee: str
+        :rtype: bool
+        """
+        url = 'rest/api/2/issue/{issue}/assignee'.format(issue=issue)
+        data = {'name': assignee}
+
+        return self.put(url, data=data)
+
     def issue_create(self, fields):
         log.warning('Creating issue "{summary}"'.format(summary=fields['summary']))
         url = 'rest/api/2/issue/'
@@ -876,7 +927,7 @@ class Jira(AtlassianRestAPI):
         data['favourite'] = 'true' if favourite else 'false'
         url = 'rest/api/2/filter'
         return self.post(url, data=data)
-    
+
     def component(self, component_id):
         return self.get('rest/api/2/component/{component_id}'.format(component_id=component_id))
 
@@ -1265,7 +1316,7 @@ class Jira(AtlassianRestAPI):
         """
         url = 'rest/agile/1.0/board/{}'.format(str(board_id))
         return self.get(url)
-    
+
     def create_agile_board(self, name, type, filter_id, location=None):
         """
         Create an agile board
@@ -1325,7 +1376,7 @@ class Jira(AtlassianRestAPI):
         """
         url = 'rest/agile/1.0/{board_id}/backlog'.format(board_id=board_id)
         return self.get(url)
-    
+
     def delete_agile_board(self, board_id):
         """
         Delete agile board by id
@@ -1342,7 +1393,7 @@ class Jira(AtlassianRestAPI):
         """
         url = 'rest/agile/1.0/board/{board_id}/properties'.format(board_id=board_id)
         return self.get(url)
-    
+
     def health_check(self):
         """
         Get health status
